@@ -38,10 +38,12 @@
 
 define ([
     'app/act-lib',
+    'app/emp-lib',
     'app/sched-lib',
     'datetime',
 ], function (
     actLib,
+    empLib,
     schedLib,
     datetime,
 ) {
@@ -128,6 +130,15 @@ define ([
             prop: 'schedEffective',
             maxlen: 30,
         },
+        ePsuperNick: {
+            name: 'ePsuperNick',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'Supervisor',
+            prop: 'ePsuperNick',
+            maxlen: 30,
+            populate: empLib.populateSupervisorNick,
+        },
         LDAPdochazka: {
             name: 'LDAPdochazka',
             aclProfileRead: 'inactive',
@@ -338,13 +349,21 @@ define ([
             text: 'Schedule ID',
             prop: 'iNsid',
             maxlen: 20,
-            populate: schedLib.populateSID,
+            // populate: schedLib.populateSID,
+        },
+        iNoffset: {
+            name: 'iNoffset',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'Offset',
+            prop: 'iNoffset',
+            maxlen: 20,
         },
         acTcode: {
             name: 'acTcode',
             aclProfileRead: 'active',
             aclProfileWrite: 'active',
-            text: 'Code',
+            text: 'Activity Code',
             prop: 'code',
             maxlen: 10,
         },
@@ -352,9 +371,10 @@ define ([
             name: 'acTaid',
             aclProfileRead: 'active',
             aclProfileWrite: 'active',
-            text: 'ID',
+            text: 'Activity ID',
             prop: 'aid',
             maxlen: 6,
+            populate: actLib.populateAIDfromCode,
         },
         acTdesc: {
             name: 'acTdesc',
@@ -371,7 +391,7 @@ define ([
             text: 'Scheduled',
             prop: 'iNschedintvls',
             maxlen: 50,
-            populate: schedLib.populateSchedIntvlsForDate,
+            // populate: schedLib.populateSchedIntvlsForDate,
         },
         iNlastexistintvl: {
             name: 'iNlastexistintvl',
